==> vtk6-6.3.0-4-aarch64.pkg.tar.xz: vtk/vtkMutableGraphHelper.java <==
// java wrapper for vtkMutableGraphHelper object
//

package vtk;
import vtk.*;

public class vtkMutableGraphHelper extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetGraph_2(vtkGraph id0);
  public void SetGraph(vtkGraph id0)
    { SetGraph_2(id0); }

  private native long GetGraph_3();
  public vtkGraph GetGraph() {
    long temp = GetGraph_3();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long AddGraphEdge_4(int id0,int id1);
  public vtkGraphEdge AddGraphEdge(int id0,int id1) {
    long temp = AddGraphEdge_4(id0,id1);

    if (temp == 0) return null;
    return (vtkGraphEdge)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int AddVertex_5();
  public int AddVertex()
    { return AddVertex_5(); }

  private native void RemoveVertex_6(int id0);
  public void RemoveVertex(int id0)
    { RemoveVertex_6(id0); }

  private native void RemoveVertices_7(vtkIdTypeArray id0);
  public void RemoveVertices(vtkIdTypeArray id0)
    { RemoveVertices_7(id0); }

  private native void RemoveEdge_8(int id0);
  public void RemoveEdge(int id0)
    { RemoveEdge_8(id0); }

  private native void RemoveEdges_9(vtkIdTypeArray id0);
  public void RemoveEdges(vtkIdTypeArray id0)
    { RemoveEdges_9(id0); }

  public vtkMutableGraphHelper() { super(); }

  public vtkMutableGraphHelper(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-aarch64.pkg.tar.xz: vtk/vtkMutableGraphHelper.java <==
// java wrapper for vtkMutableGraphHelper object
//

package vtk;
import vtk.*;

public class vtkMutableGraphHelper extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetGraph_2(vtkGraph id0);
  public void SetGraph(vtkGraph id0)
    { SetGraph_2(id0); }

  private native long GetGraph_3();
  public vtkGraph GetGraph() {
    long temp = GetGraph_3();

    if (temp == 0) return null;
    return (vtkGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long AddGraphEdge_4(int id0,int id1);
  public vtkGraphEdge AddGraphEdge(int id0,int id1) {
    long temp = AddGraphEdge_4(id0,id1);

    if (temp == 0) return null;
    return (vtkGraphEdge)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int AddVertex_5();
  public int AddVertex()
    { return AddVertex_5(); }

  private native void RemoveVertex_6(int id0);
  public void RemoveVertex(int id0)
    { RemoveVertex_6(id0); }

  private native void RemoveVertices_7(vtkIdTypeArray id0);
  public void RemoveVertices(vtkIdTypeArray id0)
    { RemoveVertices_7(id0); }

  private native void RemoveEdge_8(int id0);
  public void RemoveEdge(int id0)
    { RemoveEdge_8(id0); }

  private native void RemoveEdges_9(vtkIdTypeArray id0);
  public void RemoveEdges(vtkIdTypeArray id0)
    { RemoveEdges_9(id0); }

  public vtkMutableGraphHelper() { super(); }

  public vtkMutableGraphHelper(long id) { super(id); }
  public native long   VTKInit();

}
